@@ -9,7 +9,7 @@
 ###########################################################
 package Devel::NYTProf;
 
-our $VERSION = '6.06_03'; # also change in Devel::NYTProf::Core
+our $VERSION = '6.08_001'; # also change in Devel::NYTProf::Core
 
 package    # hide the package from the PAUSE indexer
     DB;
@@ -63,10 +63,9 @@ Devel::NYTProf - Powerful fast feature-rich Perl source code profiler
   # or into comma separated files, e.g., ./nytprof/*.csv
   nytprofcsv
 
-I give talks on profiling perl code, including a detailed look at how to use
-NYTProf and how to optimize your code, every year. A video of my YAPC::NA 2014
-talk can be found at L<https://youtu.be/T7EK6RZAnEA>
-
+Tim Bunce has often given talks on profiling perl code, including a detailed
+look at how to use NYTProf and how to optimize your code. A video of his
+YAPC::NA 2014 talk can be found at L<https://youtu.be/T7EK6RZAnEA>
 
 =head1 DESCRIPTION
 
@@ -278,7 +277,7 @@ Usually you'd load Devel::NYTProf on the command line using the perl -d option:
 
   perl -d:NYTProf some_perl.pl
 
-To save typing the ':NYTProf' you could set the PERL5DB env var 
+To save typing the ':NYTProf' you could set the L<C<PERL5DB> environment variable|perlrun/PERL5DB>:
 
   PERL5DB='use Devel::NYTProf'
 
@@ -286,7 +285,7 @@ and then just perl -d would work:
 
   perl -d some_perl.pl
 
-Or you can avoid the need to add the -d option at all by using the C<PERL5OPT> env var:
+Or you can avoid the need to add the -d option at all by using the L<C<PERL5OPT>> environment variable|perlrun/PERL5OPT>:
 
   PERL5OPT=-d:NYTProf
 
@@ -603,11 +602,6 @@ application code is sensitive to the name given to a anonymous subroutines.
 The downside is that the NYTProf reporting tools are less useful and may get
 confused if this option is used.
 
-With cperl since 5.28 and its B<usenamedanoncv> option most anon subs
-keep their old name, just with an C<@> appended. This is mostly used for
-import methods, which are skipped with perl5. The C<nameanonsubs=0> option
-is in these cases ignored.
-
 =head1 RUN-TIME CONTROL OF PROFILING
 
 You can profile only parts of an application by calling DB::disable_profile()
@@ -829,9 +823,9 @@ If you don't need statement-level profiling then you can disable it via L</stmts
 To further boost statement-level profiling performance try L</leave=0> but note that
 I<will> apportion timings for some kinds of statements less accurate).
 
-If you don't need call stacks or flamegraph then disable it via L</calls=0>.
+If you don't need call stacks or flamegraph then disable it via L<calls=0|/calls=N>.
 If you don't need subroutine profiling then you can disable it via L</subs=0>.
-If you do need it but don't need timings for perl opcodes then set L</slowops=0>.
+If you do need it but don't need timings for perl opcodes then set L<slowops=0|/slowops=N>.
 
 Generally speaking, setting calls=0 and slowops=0 will give you a useful boost
 with the least loss of detail.
@@ -1212,7 +1206,7 @@ You could also try using the L</use_db_sub=1> option.
 When using the statement profiler you may see a warning message like this:
 
   Eval '(eval 2)' (fid 9, flags:viastmt,savesrc) has unknown invoking fid 10
- 
+
 Notice that the eval file id (fid 9 in this case) is lower than the file id
 that invoked the eval (fid 10 in this case). This is a known problem caused by
 the way perl works and how the profiler assigns and outputs the file ids.
@@ -1264,12 +1258,10 @@ B<Jan Dubois> contributed the Windows port.
 B<Gisle Aas> contributed the Devel::NYTProf::ReadStream module.
 B<Steve Peters> contributed greater perl version portability and use of POSIX
 high-resolution clocks.
-B<Reini Urban> maintains the cperl fork, where it is in CORE.
 Other contributors are noted in the Changes file.
 
 Many thanks to B<Adam Kaplan> who created C<NYTProf> initially by forking
 C<Devel::FastProf> adding reporting from C<Devel::Cover> and a test suite.
-For more details see L</HISTORY> below.
 
 =head1 COPYRIGHT AND LICENSE
 
